@@ -24,10 +24,17 @@ except ImportError:  # pragma: NO COVER
 
 import grpc
 from grpc.experimental import aio
+from collections.abc import Iterable
+from google.protobuf import json_format
+import json
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 from proto.marshal.rules import wrappers
+from requests import Response
+from requests import Request, PreparedRequest
+from requests.sessions import Session
+from google.protobuf import json_format
 
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
@@ -100,6 +107,7 @@ def test__get_default_mtls_endpoint():
     [
         (FleetRoutingClient, "grpc"),
         (FleetRoutingAsyncClient, "grpc_asyncio"),
+        (FleetRoutingClient, "rest"),
     ],
 )
 def test_fleet_routing_client_from_service_account_info(client_class, transport_name):
@@ -113,7 +121,11 @@ def test_fleet_routing_client_from_service_account_info(client_class, transport_
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == ("cloudoptimization.googleapis.com:443")
+        assert client.transport._host == (
+            "cloudoptimization.googleapis.com:443"
+            if transport_name in ["grpc", "grpc_asyncio"]
+            else "https://cloudoptimization.googleapis.com"
+        )
 
 
 @pytest.mark.parametrize(
@@ -121,6 +133,7 @@ def test_fleet_routing_client_from_service_account_info(client_class, transport_
     [
         (transports.FleetRoutingGrpcTransport, "grpc"),
         (transports.FleetRoutingGrpcAsyncIOTransport, "grpc_asyncio"),
+        (transports.FleetRoutingRestTransport, "rest"),
     ],
 )
 def test_fleet_routing_client_service_account_always_use_jwt(
@@ -146,6 +159,7 @@ def test_fleet_routing_client_service_account_always_use_jwt(
     [
         (FleetRoutingClient, "grpc"),
         (FleetRoutingAsyncClient, "grpc_asyncio"),
+        (FleetRoutingClient, "rest"),
     ],
 )
 def test_fleet_routing_client_from_service_account_file(client_class, transport_name):
@@ -166,13 +180,18 @@ def test_fleet_routing_client_from_service_account_file(client_class, transport_
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == ("cloudoptimization.googleapis.com:443")
+        assert client.transport._host == (
+            "cloudoptimization.googleapis.com:443"
+            if transport_name in ["grpc", "grpc_asyncio"]
+            else "https://cloudoptimization.googleapis.com"
+        )
 
 
 def test_fleet_routing_client_get_transport_class():
     transport = FleetRoutingClient.get_transport_class()
     available_transports = [
         transports.FleetRoutingGrpcTransport,
+        transports.FleetRoutingRestTransport,
     ]
     assert transport in available_transports
 
@@ -189,6 +208,7 @@ def test_fleet_routing_client_get_transport_class():
             transports.FleetRoutingGrpcAsyncIOTransport,
             "grpc_asyncio",
         ),
+        (FleetRoutingClient, transports.FleetRoutingRestTransport, "rest"),
     ],
 )
 @mock.patch.object(
@@ -332,6 +352,8 @@ def test_fleet_routing_client_client_options(
             "grpc_asyncio",
             "false",
         ),
+        (FleetRoutingClient, transports.FleetRoutingRestTransport, "rest", "true"),
+        (FleetRoutingClient, transports.FleetRoutingRestTransport, "rest", "false"),
     ],
 )
 @mock.patch.object(
@@ -525,6 +547,7 @@ def test_fleet_routing_client_get_mtls_endpoint_and_cert_source(client_class):
             transports.FleetRoutingGrpcAsyncIOTransport,
             "grpc_asyncio",
         ),
+        (FleetRoutingClient, transports.FleetRoutingRestTransport, "rest"),
     ],
 )
 def test_fleet_routing_client_client_options_scopes(
@@ -565,6 +588,7 @@ def test_fleet_routing_client_client_options_scopes(
             "grpc_asyncio",
             grpc_helpers_async,
         ),
+        (FleetRoutingClient, transports.FleetRoutingRestTransport, "rest", None),
     ],
 )
 def test_fleet_routing_client_client_options_credentials_file(
@@ -984,6 +1008,438 @@ async def test_batch_optimize_tours_field_headers_async():
     ) in kw["metadata"]
 
 
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        fleet_routing.OptimizeToursRequest,
+        dict,
+    ],
+)
+def test_optimize_tours_rest(request_type):
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"parent": "projects/sample1/locations/sample2"}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(type(client.transport._session), "request") as req:
+        # Designate an appropriate value for the returned response.
+        return_value = fleet_routing.OptimizeToursResponse(
+            request_label="request_label_value",
+            total_cost=0.10840000000000001,
+        )
+
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 200
+        pb_return_value = fleet_routing.OptimizeToursResponse.pb(return_value)
+        json_return_value = json_format.MessageToJson(pb_return_value)
+
+        response_value._content = json_return_value.encode("UTF-8")
+        req.return_value = response_value
+        response = client.optimize_tours(request)
+
+    # Establish that the response is the type that we expect.
+    assert isinstance(response, fleet_routing.OptimizeToursResponse)
+    assert response.request_label == "request_label_value"
+    assert math.isclose(response.total_cost, 0.10840000000000001, rel_tol=1e-6)
+
+
+def test_optimize_tours_rest_required_fields(
+    request_type=fleet_routing.OptimizeToursRequest,
+):
+    transport_class = transports.FleetRoutingRestTransport
+
+    request_init = {}
+    request_init["parent"] = ""
+    request = request_type(**request_init)
+    pb_request = request_type.pb(request)
+    jsonified_request = json.loads(
+        json_format.MessageToJson(
+            pb_request,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
+        )
+    )
+
+    # verify fields with default values are dropped
+
+    unset_fields = transport_class(
+        credentials=ga_credentials.AnonymousCredentials()
+    ).optimize_tours._get_unset_required_fields(jsonified_request)
+    jsonified_request.update(unset_fields)
+
+    # verify required fields with default values are now present
+
+    jsonified_request["parent"] = "parent_value"
+
+    unset_fields = transport_class(
+        credentials=ga_credentials.AnonymousCredentials()
+    ).optimize_tours._get_unset_required_fields(jsonified_request)
+    jsonified_request.update(unset_fields)
+
+    # verify required fields with non-default values are left alone
+    assert "parent" in jsonified_request
+    assert jsonified_request["parent"] == "parent_value"
+
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+    request = request_type(**request_init)
+
+    # Designate an appropriate value for the returned response.
+    return_value = fleet_routing.OptimizeToursResponse()
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(Session, "request") as req:
+        # We need to mock transcode() because providing default values
+        # for required fields will fail the real version if the http_options
+        # expect actual values for those fields.
+        with mock.patch.object(path_template, "transcode") as transcode:
+            # A uri without fields and an empty body will force all the
+            # request fields to show up in the query_params.
+            pb_request = request_type.pb(request)
+            transcode_result = {
+                "uri": "v1/sample_method",
+                "method": "post",
+                "query_params": pb_request,
+            }
+            transcode_result["body"] = pb_request
+            transcode.return_value = transcode_result
+
+            response_value = Response()
+            response_value.status_code = 200
+
+            pb_return_value = fleet_routing.OptimizeToursResponse.pb(return_value)
+            json_return_value = json_format.MessageToJson(pb_return_value)
+
+            response_value._content = json_return_value.encode("UTF-8")
+            req.return_value = response_value
+
+            response = client.optimize_tours(request)
+
+            expected_params = [("$alt", "json;enum-encoding=int")]
+            actual_params = req.call_args.kwargs["params"]
+            assert expected_params == actual_params
+
+
+def test_optimize_tours_rest_unset_required_fields():
+    transport = transports.FleetRoutingRestTransport(
+        credentials=ga_credentials.AnonymousCredentials
+    )
+
+    unset_fields = transport.optimize_tours._get_unset_required_fields({})
+    assert set(unset_fields) == (set(()) & set(("parent",)))
+
+
+@pytest.mark.parametrize("null_interceptor", [True, False])
+def test_optimize_tours_rest_interceptors(null_interceptor):
+    transport = transports.FleetRoutingRestTransport(
+        credentials=ga_credentials.AnonymousCredentials(),
+        interceptor=None
+        if null_interceptor
+        else transports.FleetRoutingRestInterceptor(),
+    )
+    client = FleetRoutingClient(transport=transport)
+    with mock.patch.object(
+        type(client.transport._session), "request"
+    ) as req, mock.patch.object(
+        path_template, "transcode"
+    ) as transcode, mock.patch.object(
+        transports.FleetRoutingRestInterceptor, "post_optimize_tours"
+    ) as post, mock.patch.object(
+        transports.FleetRoutingRestInterceptor, "pre_optimize_tours"
+    ) as pre:
+        pre.assert_not_called()
+        post.assert_not_called()
+        pb_message = fleet_routing.OptimizeToursRequest.pb(
+            fleet_routing.OptimizeToursRequest()
+        )
+        transcode.return_value = {
+            "method": "post",
+            "uri": "my_uri",
+            "body": pb_message,
+            "query_params": pb_message,
+        }
+
+        req.return_value = Response()
+        req.return_value.status_code = 200
+        req.return_value.request = PreparedRequest()
+        req.return_value._content = fleet_routing.OptimizeToursResponse.to_json(
+            fleet_routing.OptimizeToursResponse()
+        )
+
+        request = fleet_routing.OptimizeToursRequest()
+        metadata = [
+            ("key", "val"),
+            ("cephalopod", "squid"),
+        ]
+        pre.return_value = request, metadata
+        post.return_value = fleet_routing.OptimizeToursResponse()
+
+        client.optimize_tours(
+            request,
+            metadata=[
+                ("key", "val"),
+                ("cephalopod", "squid"),
+            ],
+        )
+
+        pre.assert_called_once()
+        post.assert_called_once()
+
+
+def test_optimize_tours_rest_bad_request(
+    transport: str = "rest", request_type=fleet_routing.OptimizeToursRequest
+):
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"parent": "projects/sample1/locations/sample2"}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a BadRequest error.
+    with mock.patch.object(Session, "request") as req, pytest.raises(
+        core_exceptions.BadRequest
+    ):
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 400
+        response_value.request = Request()
+        req.return_value = response_value
+        client.optimize_tours(request)
+
+
+def test_optimize_tours_rest_error():
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport="rest"
+    )
+
+
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        fleet_routing.BatchOptimizeToursRequest,
+        dict,
+    ],
+)
+def test_batch_optimize_tours_rest(request_type):
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"parent": "projects/sample1/locations/sample2"}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(type(client.transport._session), "request") as req:
+        # Designate an appropriate value for the returned response.
+        return_value = operations_pb2.Operation(name="operations/spam")
+
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 200
+        json_return_value = json_format.MessageToJson(return_value)
+
+        response_value._content = json_return_value.encode("UTF-8")
+        req.return_value = response_value
+        response = client.batch_optimize_tours(request)
+
+    # Establish that the response is the type that we expect.
+    assert response.operation.name == "operations/spam"
+
+
+def test_batch_optimize_tours_rest_required_fields(
+    request_type=fleet_routing.BatchOptimizeToursRequest,
+):
+    transport_class = transports.FleetRoutingRestTransport
+
+    request_init = {}
+    request_init["parent"] = ""
+    request = request_type(**request_init)
+    pb_request = request_type.pb(request)
+    jsonified_request = json.loads(
+        json_format.MessageToJson(
+            pb_request,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
+        )
+    )
+
+    # verify fields with default values are dropped
+
+    unset_fields = transport_class(
+        credentials=ga_credentials.AnonymousCredentials()
+    ).batch_optimize_tours._get_unset_required_fields(jsonified_request)
+    jsonified_request.update(unset_fields)
+
+    # verify required fields with default values are now present
+
+    jsonified_request["parent"] = "parent_value"
+
+    unset_fields = transport_class(
+        credentials=ga_credentials.AnonymousCredentials()
+    ).batch_optimize_tours._get_unset_required_fields(jsonified_request)
+    jsonified_request.update(unset_fields)
+
+    # verify required fields with non-default values are left alone
+    assert "parent" in jsonified_request
+    assert jsonified_request["parent"] == "parent_value"
+
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+    request = request_type(**request_init)
+
+    # Designate an appropriate value for the returned response.
+    return_value = operations_pb2.Operation(name="operations/spam")
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(Session, "request") as req:
+        # We need to mock transcode() because providing default values
+        # for required fields will fail the real version if the http_options
+        # expect actual values for those fields.
+        with mock.patch.object(path_template, "transcode") as transcode:
+            # A uri without fields and an empty body will force all the
+            # request fields to show up in the query_params.
+            pb_request = request_type.pb(request)
+            transcode_result = {
+                "uri": "v1/sample_method",
+                "method": "post",
+                "query_params": pb_request,
+            }
+            transcode_result["body"] = pb_request
+            transcode.return_value = transcode_result
+
+            response_value = Response()
+            response_value.status_code = 200
+            json_return_value = json_format.MessageToJson(return_value)
+
+            response_value._content = json_return_value.encode("UTF-8")
+            req.return_value = response_value
+
+            response = client.batch_optimize_tours(request)
+
+            expected_params = [("$alt", "json;enum-encoding=int")]
+            actual_params = req.call_args.kwargs["params"]
+            assert expected_params == actual_params
+
+
+def test_batch_optimize_tours_rest_unset_required_fields():
+    transport = transports.FleetRoutingRestTransport(
+        credentials=ga_credentials.AnonymousCredentials
+    )
+
+    unset_fields = transport.batch_optimize_tours._get_unset_required_fields({})
+    assert set(unset_fields) == (
+        set(())
+        & set(
+            (
+                "parent",
+                "modelConfigs",
+            )
+        )
+    )
+
+
+@pytest.mark.parametrize("null_interceptor", [True, False])
+def test_batch_optimize_tours_rest_interceptors(null_interceptor):
+    transport = transports.FleetRoutingRestTransport(
+        credentials=ga_credentials.AnonymousCredentials(),
+        interceptor=None
+        if null_interceptor
+        else transports.FleetRoutingRestInterceptor(),
+    )
+    client = FleetRoutingClient(transport=transport)
+    with mock.patch.object(
+        type(client.transport._session), "request"
+    ) as req, mock.patch.object(
+        path_template, "transcode"
+    ) as transcode, mock.patch.object(
+        operation.Operation, "_set_result_from_operation"
+    ), mock.patch.object(
+        transports.FleetRoutingRestInterceptor, "post_batch_optimize_tours"
+    ) as post, mock.patch.object(
+        transports.FleetRoutingRestInterceptor, "pre_batch_optimize_tours"
+    ) as pre:
+        pre.assert_not_called()
+        post.assert_not_called()
+        pb_message = fleet_routing.BatchOptimizeToursRequest.pb(
+            fleet_routing.BatchOptimizeToursRequest()
+        )
+        transcode.return_value = {
+            "method": "post",
+            "uri": "my_uri",
+            "body": pb_message,
+            "query_params": pb_message,
+        }
+
+        req.return_value = Response()
+        req.return_value.status_code = 200
+        req.return_value.request = PreparedRequest()
+        req.return_value._content = json_format.MessageToJson(
+            operations_pb2.Operation()
+        )
+
+        request = fleet_routing.BatchOptimizeToursRequest()
+        metadata = [
+            ("key", "val"),
+            ("cephalopod", "squid"),
+        ]
+        pre.return_value = request, metadata
+        post.return_value = operations_pb2.Operation()
+
+        client.batch_optimize_tours(
+            request,
+            metadata=[
+                ("key", "val"),
+                ("cephalopod", "squid"),
+            ],
+        )
+
+        pre.assert_called_once()
+        post.assert_called_once()
+
+
+def test_batch_optimize_tours_rest_bad_request(
+    transport: str = "rest", request_type=fleet_routing.BatchOptimizeToursRequest
+):
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"parent": "projects/sample1/locations/sample2"}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a BadRequest error.
+    with mock.patch.object(Session, "request") as req, pytest.raises(
+        core_exceptions.BadRequest
+    ):
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 400
+        response_value.request = Request()
+        req.return_value = response_value
+        client.batch_optimize_tours(request)
+
+
+def test_batch_optimize_tours_rest_error():
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport="rest"
+    )
+
+
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.FleetRoutingGrpcTransport(
@@ -1065,6 +1521,7 @@ def test_transport_get_channel():
     [
         transports.FleetRoutingGrpcTransport,
         transports.FleetRoutingGrpcAsyncIOTransport,
+        transports.FleetRoutingRestTransport,
     ],
 )
 def test_transport_adc(transport_class):
@@ -1079,6 +1536,7 @@ def test_transport_adc(transport_class):
     "transport_name",
     [
         "grpc",
+        "rest",
     ],
 )
 def test_transport_kind(transport_name):
@@ -1215,6 +1673,7 @@ def test_fleet_routing_transport_auth_adc(transport_class):
     [
         transports.FleetRoutingGrpcTransport,
         transports.FleetRoutingGrpcAsyncIOTransport,
+        transports.FleetRoutingRestTransport,
     ],
 )
 def test_fleet_routing_transport_auth_gdch_credentials(transport_class):
@@ -1309,11 +1768,40 @@ def test_fleet_routing_grpc_transport_client_cert_source_for_mtls(transport_clas
             )
 
 
+def test_fleet_routing_http_transport_client_cert_source_for_mtls():
+    cred = ga_credentials.AnonymousCredentials()
+    with mock.patch(
+        "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
+    ) as mock_configure_mtls_channel:
+        transports.FleetRoutingRestTransport(
+            credentials=cred, client_cert_source_for_mtls=client_cert_source_callback
+        )
+        mock_configure_mtls_channel.assert_called_once_with(client_cert_source_callback)
+
+
+def test_fleet_routing_rest_lro_client():
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+    transport = client.transport
+
+    # Ensure that we have a api-core operations client.
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.AbstractOperationsClient,
+    )
+
+    # Ensure that subsequent calls to the property send the exact same object.
+    assert transport.operations_client is transport.operations_client
+
+
 @pytest.mark.parametrize(
     "transport_name",
     [
         "grpc",
         "grpc_asyncio",
+        "rest",
     ],
 )
 def test_fleet_routing_host_no_port(transport_name):
@@ -1324,7 +1812,11 @@ def test_fleet_routing_host_no_port(transport_name):
         ),
         transport=transport_name,
     )
-    assert client.transport._host == ("cloudoptimization.googleapis.com:443")
+    assert client.transport._host == (
+        "cloudoptimization.googleapis.com:443"
+        if transport_name in ["grpc", "grpc_asyncio"]
+        else "https://cloudoptimization.googleapis.com"
+    )
 
 
 @pytest.mark.parametrize(
@@ -1332,6 +1824,7 @@ def test_fleet_routing_host_no_port(transport_name):
     [
         "grpc",
         "grpc_asyncio",
+        "rest",
     ],
 )
 def test_fleet_routing_host_with_port(transport_name):
@@ -1342,7 +1835,36 @@ def test_fleet_routing_host_with_port(transport_name):
         ),
         transport=transport_name,
     )
-    assert client.transport._host == ("cloudoptimization.googleapis.com:8000")
+    assert client.transport._host == (
+        "cloudoptimization.googleapis.com:8000"
+        if transport_name in ["grpc", "grpc_asyncio"]
+        else "https://cloudoptimization.googleapis.com:8000"
+    )
+
+
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "rest",
+    ],
+)
+def test_fleet_routing_client_transport_session_collision(transport_name):
+    creds1 = ga_credentials.AnonymousCredentials()
+    creds2 = ga_credentials.AnonymousCredentials()
+    client1 = FleetRoutingClient(
+        credentials=creds1,
+        transport=transport_name,
+    )
+    client2 = FleetRoutingClient(
+        credentials=creds2,
+        transport=transport_name,
+    )
+    session1 = client1.transport.optimize_tours._session
+    session2 = client2.transport.optimize_tours._session
+    assert session1 != session2
+    session1 = client1.transport.batch_optimize_tours._session
+    session2 = client2.transport.batch_optimize_tours._session
+    assert session1 != session2
 
 
 def test_fleet_routing_grpc_transport_channel():
@@ -1637,6 +2159,64 @@ async def test_transport_close_async():
         close.assert_called_once()
 
 
+def test_get_operation_rest_bad_request(
+    transport: str = "rest", request_type=operations_pb2.GetOperationRequest
+):
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    request = request_type()
+    request = json_format.ParseDict(
+        {"name": "projects/sample1/operations/sample2"}, request
+    )
+
+    # Mock the http request call within the method and fake a BadRequest error.
+    with mock.patch.object(Session, "request") as req, pytest.raises(
+        core_exceptions.BadRequest
+    ):
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 400
+        response_value.request = Request()
+        req.return_value = response_value
+        client.get_operation(request)
+
+
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        operations_pb2.GetOperationRequest,
+        dict,
+    ],
+)
+def test_get_operation_rest(request_type):
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+    request_init = {"name": "projects/sample1/operations/sample2"}
+    request = request_type(**request_init)
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(type(client.transport._session), "request") as req:
+        # Designate an appropriate value for the returned response.
+        return_value = operations_pb2.Operation()
+
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 200
+        json_return_value = json_format.MessageToJson(return_value)
+
+        response_value._content = json_return_value.encode("UTF-8")
+        req.return_value = response_value
+
+        response = client.get_operation(request)
+
+    # Establish that the response is the type that we expect.
+    assert isinstance(response, operations_pb2.Operation)
+
+
 def test_get_operation(transport: str = "grpc"):
     client = FleetRoutingClient(
         credentials=ga_credentials.AnonymousCredentials(),
@@ -1784,6 +2364,7 @@ async def test_get_operation_from_dict_async():
 
 def test_transport_close():
     transports = {
+        "rest": "_session",
         "grpc": "_grpc_channel",
     }
 
@@ -1801,6 +2382,7 @@ def test_transport_close():
 
 def test_client_ctx():
     transports = [
+        "rest",
         "grpc",
     ]
     for transport in transports:
